[crypticl-cvs] CVS update: crypticl/src/aes.lisp crypticl/src/common.lisp crypticl/src/crypticl-package.lisp crypticl/src/des.lisp crypticl/src/diffie-hellman.lisp crypticl/src/dsa.lisp crypticl/src/idea.lisp crypticl/src/keygenerator.lisp crypticl/src/keystore.lisp crypticl/src/load.lisp crypticl/src/md5.lisp crypticl/src/numtheory.lisp crypticl/src/random.lisp crypticl/src/rsa.lisp crypticl/src/sha.lisp crypticl/src/test.lisp crypticl/src/utilities.lisp

Taale Skogan tskogan at common-lisp.net
Thu Nov 25 21:57:21 UTC 2004


Update of /project/crypticl/cvsroot/crypticl/src
In directory common-lisp.net:/tmp/cvs-serv29823/src

Modified Files:
	aes.lisp common.lisp crypticl-package.lisp des.lisp 
	diffie-hellman.lisp dsa.lisp idea.lisp keygenerator.lisp 
	keystore.lisp load.lisp md5.lisp numtheory.lisp random.lisp 
	rsa.lisp sha.lisp test.lisp utilities.lisp 
Log Message:
Removed allegro specific excl: function. Still one left.
Using aa instead of the norwegian character å in my name.
Renamed various versions of TO DO: to To do: at the top of the files.
Using TODO inside the source.

Date: Thu Nov 25 22:56:54 2004
Author: tskogan

Index: crypticl/src/aes.lisp
diff -u crypticl/src/aes.lisp:1.4 crypticl/src/aes.lisp:1.5
--- crypticl/src/aes.lisp:1.4	Wed Nov 24 23:54:38 2004
+++ crypticl/src/aes.lisp	Thu Nov 25 22:56:51 2004
@@ -2,7 +2,7 @@
 ;;;; The Crypticl cryptographic library.
 ;;;;
 ;;;; Description: AES
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 
 ;;To do:


Index: crypticl/src/common.lisp
diff -u crypticl/src/common.lisp:1.2 crypticl/src/common.lisp:1.3
--- crypticl/src/common.lisp:1.2	Sun Nov  7 01:17:35 2004
+++ crypticl/src/common.lisp	Thu Nov 25 22:56:52 2004
@@ -2,12 +2,13 @@
 ;;;; The Crypticl cryptographic library.
 ;;;;
 ;;;; Description: Common functionality.
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 
-;; TO DO:
+;; To do:
 ;;-register constructors for byte-encoding constructors in the same way as for normal constructors.
 ;;-better spki string encoding with type.
+;;-replace excl function
 
 (in-package crypticl)
 
@@ -230,6 +231,7 @@
 
 (defun get-element-encodings (msg-elements)
   "Get byte encoding for each msg element, transform to base64 spki and return the bytes."
+  ;;TODO replace excl function
   (excl:string-to-octets
    (to-spki (mapcar #'get-msg-element-encoding msg-elements))))
 


Index: crypticl/src/crypticl-package.lisp
diff -u crypticl/src/crypticl-package.lisp:1.6 crypticl/src/crypticl-package.lisp:1.7
--- crypticl/src/crypticl-package.lisp:1.6	Sun Nov 14 20:56:29 2004
+++ crypticl/src/crypticl-package.lisp	Thu Nov 25 22:56:52 2004
@@ -6,10 +6,10 @@
 ;;;; Usage: Loading this file will load the rest of the library.
 ;;;;        After loading you can list the public interface with 
 ;;;;        (crypticl:print-external-symbols) from the top-level. 
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 
-;;TO DO
+;;To do:
 
 (in-package cl-user)
 


Index: crypticl/src/des.lisp
diff -u crypticl/src/des.lisp:1.2 crypticl/src/des.lisp:1.3
--- crypticl/src/des.lisp:1.2	Sun Nov  7 01:17:35 2004
+++ crypticl/src/des.lisp	Thu Nov 25 22:56:52 2004
@@ -2,7 +2,7 @@
 ;;;; The Crypticl cryptographic library.
 ;;;;
 ;;;; Description: A void DES implementation.
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 
 ;;; DES has not been implemented, but a DES class and some


Index: crypticl/src/diffie-hellman.lisp
diff -u crypticl/src/diffie-hellman.lisp:1.4 crypticl/src/diffie-hellman.lisp:1.5
--- crypticl/src/diffie-hellman.lisp:1.4	Sun Nov  7 21:23:33 2004
+++ crypticl/src/diffie-hellman.lisp	Thu Nov 25 22:56:52 2004
@@ -2,7 +2,7 @@
 ;;;; The Crypticl cryptographic library.
 ;;;;
 ;;;; Description: Diffie-Hellman
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 
 


Index: crypticl/src/dsa.lisp
diff -u crypticl/src/dsa.lisp:1.5 crypticl/src/dsa.lisp:1.6
--- crypticl/src/dsa.lisp:1.5	Sun Nov 14 00:10:39 2004
+++ crypticl/src/dsa.lisp	Thu Nov 25 22:56:52 2004
@@ -2,7 +2,7 @@
 ;;;; The Crypticl cryptographic library.
 ;;;;
 ;;;; Description: The Digital Signature Algorithm (DSA).
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 
 ;;; Implementation based on the Digital Signature Standard (DSS) ([1]). 
@@ -10,7 +10,7 @@
 ;;;
 ;;; [1] NIST. 2000. Digital Signature Standard (DSS). FIPS Pub 186-2.
 
-;;TO DO:
+;;To do:
 
 (in-package crypticl)
 


Index: crypticl/src/idea.lisp
diff -u crypticl/src/idea.lisp:1.3 crypticl/src/idea.lisp:1.4
--- crypticl/src/idea.lisp:1.3	Sun Nov  7 13:04:17 2004
+++ crypticl/src/idea.lisp	Thu Nov 25 22:56:52 2004
@@ -2,7 +2,7 @@
 ;;;; The Crypticl cryptographic library.
 ;;;;
 ;;;; Description: IDEA - International Data Encryption Algorithm
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 
 ;;; Based on the references [1] and [2].


Index: crypticl/src/keygenerator.lisp
diff -u crypticl/src/keygenerator.lisp:1.5 crypticl/src/keygenerator.lisp:1.6
--- crypticl/src/keygenerator.lisp:1.5	Sun Nov 14 00:10:39 2004
+++ crypticl/src/keygenerator.lisp	Thu Nov 25 22:56:52 2004
@@ -2,10 +2,10 @@
 ;;;; The Crypticl cryptographic library.
 ;;;;
 ;;;; Description: Interface for key generation. 
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 
-;;TO DO
+;;To do:
 
 (in-package crypticl)
 


Index: crypticl/src/load.lisp
diff -u crypticl/src/load.lisp:1.5 crypticl/src/load.lisp:1.6
--- crypticl/src/load.lisp:1.5	Wed Nov 24 23:54:38 2004
+++ crypticl/src/load.lisp	Thu Nov 25 22:56:52 2004
@@ -6,22 +6,18 @@
 ;;;; Usage: Loading this file will load the rest of the library.
 ;;;;        After loading you can list the public interface with 
 ;;;;        (crypticl:print-external-symbols) from the top-level. 
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 
-;;To-do:
-;;-port this to non-Allegro lisps.  excl: is Allegro spesific.  Clisp 
-;; chokes on the Norwegian charachter in Tåle (above).
+;;To do:
 
 (in-package cl-user)
 
 ;;(proclaim '(optimize (speed 2) (safety 1) (space 1) (debug 3)))
 
 
-;; Load library. If fast-load is true, do quick load without recompiling.
-;; NB! The order of the file names in the list  matter.
-(let ((fast-load t)
-      (files '("crypticl-package"
+;; Load library. NB! The order of the file names in the list  matter.
+(let ((files '("crypticl-package"
 	       "utilities" 
 	       "numtheory"
 	       "common"
@@ -38,9 +34,7 @@
 	     :device (pathname-device *load-pathname*)
 	     :directory (directory-namestring *load-pathname*)))
 	   (module (merge-pathnames file path)))
-      (if fast-load
-	  (excl::compile-file-if-needed module)    
-	(compile-file module :verbose nil))
+      (compile-file module :verbose nil)
       (load module))))
 
 


Index: crypticl/src/md5.lisp
diff -u crypticl/src/md5.lisp:1.2 crypticl/src/md5.lisp:1.3
--- crypticl/src/md5.lisp:1.2	Sun Nov  7 01:17:35 2004
+++ crypticl/src/md5.lisp	Thu Nov 25 22:56:52 2004
@@ -2,7 +2,7 @@
 ;;;; The Crypticl cryptographic library.
 ;;;;
 ;;;; Description: The RSA MD5 message digest algorithm from Internet RFC 1321.
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 ;;;; Credit: Low level code based on implementation by Mark Nahabedian with 
 ;;;;         enhancements by Tony Eng.


Index: crypticl/src/numtheory.lisp
diff -u crypticl/src/numtheory.lisp:1.2 crypticl/src/numtheory.lisp:1.3
--- crypticl/src/numtheory.lisp:1.2	Sun Nov  7 01:17:35 2004
+++ crypticl/src/numtheory.lisp	Thu Nov 25 22:56:52 2004
@@ -2,7 +2,7 @@
 ;;;; The Crypticl cryptographic library.
 ;;;;
 ;;;; Description:  Number theoretic utilities, including primality testing.
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 
 ;;; References:
@@ -10,8 +10,7 @@
 ;;; [2] Stinson,D.R. 2002. "Cryptography - Theory and Practice"
 ;;; [3] Rosen, K.H. 1993. "Elementary Number Theory" 3rd
 
-;;TO DO
-
+;;To do:
 
 (in-package crypticl)
 


Index: crypticl/src/random.lisp
diff -u crypticl/src/random.lisp:1.2 crypticl/src/random.lisp:1.3
--- crypticl/src/random.lisp:1.2	Sun Nov  7 01:17:35 2004
+++ crypticl/src/random.lisp	Thu Nov 25 22:56:52 2004
@@ -2,11 +2,11 @@
 ;;;; The Crypticl cryptographic library.
 ;;;;
 ;;;; Description: Pseudo random number generation.
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 
 
-;;TO DO
+;;To do:
 ;;-get high entropy bits on non-Linux system. Either roll your own (most likely bad idea) or use win32API to handle one other system. But this is not important. win32 API CryptGenRandom.
 ;;-test suite. Some simple statistical tests on output?
 


Index: crypticl/src/rsa.lisp
diff -u crypticl/src/rsa.lisp:1.4 crypticl/src/rsa.lisp:1.5
--- crypticl/src/rsa.lisp:1.4	Sun Nov 14 00:10:39 2004
+++ crypticl/src/rsa.lisp	Thu Nov 25 22:56:53 2004
@@ -2,13 +2,13 @@
 ;;;; The Crypticl cryptographic library.
 ;;;;
 ;;;; Description: RSA encryption/decryption according to PKCS#1
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 
 ;;; References:
 ;;; [1] RFC 2313 Kaliski, B. 1998. PKCS #1: RSA Encryption.
 
-;;TO DO
+;;To do:
 ;; - PKCS#1 parser is not correct for type 0 (but that is a poor byte type anyway ans is not likely to be used)
 
 (in-package crypticl)


Index: crypticl/src/sha.lisp
diff -u crypticl/src/sha.lisp:1.3 crypticl/src/sha.lisp:1.4
--- crypticl/src/sha.lisp:1.3	Wed Nov 24 23:54:38 2004
+++ crypticl/src/sha.lisp	Thu Nov 25 22:56:53 2004
@@ -2,7 +2,7 @@
 ;;;; The Crypticl cryptographic library.
 ;;;;
 ;;;; Description: The SHA-1 message digest algorithm.
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 
 


Index: crypticl/src/test.lisp
diff -u crypticl/src/test.lisp:1.3 crypticl/src/test.lisp:1.4
--- crypticl/src/test.lisp:1.3	Sun Nov 14 20:56:29 2004
+++ crypticl/src/test.lisp	Thu Nov 25 22:56:53 2004
@@ -2,7 +2,7 @@
 ;;;; The Crypticl cryptographic library.
 ;;;;
 ;;;; Description: Test code for the library.
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 
 (in-package crypticl)


Index: crypticl/src/utilities.lisp
diff -u crypticl/src/utilities.lisp:1.2 crypticl/src/utilities.lisp:1.3
--- crypticl/src/utilities.lisp:1.2	Sun Nov  7 01:17:35 2004
+++ crypticl/src/utilities.lisp	Thu Nov 25 22:56:53 2004
@@ -2,10 +2,10 @@
 ;;;; The Crypticl cryptographic library.
 ;;;;
 ;;;; Description: Non-cryptopgrahic utilities
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 
-;;TO DO
+;;To do:
 ;;-testvectors
 
 (in-package crypticl)





More information about the Crypticl-cvs mailing list
Index: crypticl/src/keystore.lisp
diff -u crypticl/src/keystore.lisp:1.2 crypticl/src/keystore.lisp:1.3
--- crypticl/src/keystore.lisp:1.2	Sun Nov 14 20:56:29 2004
+++ crypticl/src/keystore.lisp	Thu Nov 25 22:56:52 2004
@@ -2,15 +2,15 @@
 ;;;; The Crypticl cryptographic library.
 ;;;;
 ;;;; Description: Simple key store utility.
 ;;;; Author: Tåle Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 
-;;TO DO
+;;To do:
 
 
 ;; Printed representation of KeyStore object
 ;; users:
-;;( (("Tåle Skogan" "tasko at stud.cs.uit.no"...) ("22ffee" "55aadd" ...))
+;;( (("Taale Skogan" "tasko at stud.cs.uit.no"...) ("22ffee" "55aadd" ...))
 ;;  (("Ross Anderson" "ross at acm.org" ...) ("eeff34"..:)))
 ;; ht:
 ;; "22ffee" -> #<RSAPrivateKey @ #x211f58ba>
@@ -44,7 +44,7 @@
 		      (parse-integer (nth 4 tokens))))
 
 #|
-"Tåle Skogan" "tasko at stud.cs.uit.no"  - first line
+"Taale Skogan" "tasko at stud.cs.uit.no"  - first line
 RSAPublicKey "22ffee" 5 119         - one line per key
 RSAPrivateKey "22ffee" 77 119
 ****                                - separator between users
@@ -143,7 +143,7 @@
   (gethash fingerprint (ht obj)))
 
 #|
-"Tåle Skogan" "tasko at stud.cs.uit.no"  - first line
+"Taale Skogan" "tasko at stud.cs.uit.no"  - first line
 RSAPublicKey "22ffee" 5 119         - one line per key
 RSAPrivateKey "22ffee" 77 119
 ****                                - separator between users
@@ -2,15 +2,15 @@
 ;;;;
 ;;;; Description: Simple key store utility.
-;;;; Author: Tåle Skogan <tasko at frisurf.no>
+;;;; Author: Taale Skogan <tasko at frisurf.no>
 ;;;; Distribution:  See the accompanying file LICENSE.
 

